ShutUp

Struct ShutUp 

pub struct ShutUp(/* private fields */);
A shutdown handle.

Children

“Children” can be created by invoking the Self::child method. A children is another shutdown handle that would automatically be shut down if the parent is shut down.

Circular Reference

The bahaviour is undefined if circular reference of children occurs.

One-time Usage

This is designed for one-time usage for managing shutdown signals. The bahaviour is undefined if Self::shut is called for multiple times.

Implementations

Source

impl ShutUp

pub fn child(&self) -> Self

Create a child of this shutdown handle.

pub fn adopt(&self, child: &Self)

Adopt another shutdown handle as child.

pub fn new() -> Self

Create a new shutdown handle.

pub fn wait(&self) -> impl Wait

Wait until a shutdown signal is received.

pub fn off(&self) -> bool

Check whether this handle is shut down.

Used for polling shutdown status instead of wait asynchronously for shutdown.

pub fn register_hook(&self, hook: impl FnOnce() + Send + 'static)

Register a hook to be run when this handle is shut down.

pub fn shut(&self)

Triggers shutdown on the current handle and its children.