pub struct ShutUp(/* private fields */);Expand description
A shutdown handle.
Children
“Children” can be created by invoking the Self::child method.
A children is another shutdown handle that would automatically be shut down if the parent is shut down.
Circular Reference
The bahaviour is undefined if circular reference of children occurs.
One-time Usage
This is designed for one-time usage for managing shutdown signals.
The bahaviour is undefined if Self::shut is called for multiple times.
Implementations